@@ -3,7 +3,7 @@ use anyhow::Result;
 use crate::Client;
 
 pub struct Packages {
-    client: Client,
+    pub client: Client,
 }
 
 impl Packages {
@@ -112,23 +112,17 @@ impl Packages {
         org: &str,
         token: &str,
     ) -> Result<()> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if !token.is_empty() {
-            query_args.push(format!("token={}", token));
-        }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+            query_args.push(("token".to_string(), token.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/orgs/{}/packages/{}/{}/restore?{}",
             crate::progenitor_support::encode_path(&org.to_string()),
             crate::progenitor_support::encode_path(&package_type.to_string()),
             crate::progenitor_support::encode_path(&package_name.to_string()),
-            query
+            query_
         );
 
         self.client.post(&url, None).await
@@ -164,27 +158,23 @@ impl Packages {
         per_page: i64,
         state: crate::types::PackagesGetAllPackageVersionsOwnedByOrgState,
     ) -> Result<Vec<crate::types::PackageVersion>> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if page > 0 {
-            query_args.push(format!("page={}", page));
+            query_args.push(("page".to_string(), page.to_string()));
         }
         if per_page > 0 {
-            query_args.push(format!("per_page={}", per_page));
+            query_args.push(("per_page".to_string(), per_page.to_string()));
         }
-        query_args.push(format!("state={}", state));
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+        if !state.to_string().is_empty() {
+            query_args.push(("state".to_string(), state.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/orgs/{}/packages/{}/{}/versions?{}",
             crate::progenitor_support::encode_path(&org.to_string()),
             crate::progenitor_support::encode_path(&package_type.to_string()),
             crate::progenitor_support::encode_path(&package_name.to_string()),
-            query
+            query_
         );
 
         self.client.get(&url, None).await
@@ -211,21 +201,17 @@ impl Packages {
         org: &str,
         state: crate::types::PackagesGetAllPackageVersionsOwnedByOrgState,
     ) -> Result<Vec<crate::types::PackageVersion>> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
-        query_args.push(format!("state={}", state));
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+        let mut query_args: Vec<(String, String)> = Default::default();
+        if !state.to_string().is_empty() {
+            query_args.push(("state".to_string(), state.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/orgs/{}/packages/{}/{}/versions?{}",
             crate::progenitor_support::encode_path(&org.to_string()),
             crate::progenitor_support::encode_path(&package_type.to_string()),
             crate::progenitor_support::encode_path(&package_name.to_string()),
-            query
+            query_
         );
 
         self.client.get_all_pages(&url, None).await
@@ -437,22 +423,16 @@ impl Packages {
         package_name: &str,
         token: &str,
     ) -> Result<()> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if !token.is_empty() {
-            query_args.push(format!("token={}", token));
-        }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+            query_args.push(("token".to_string(), token.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/user/packages/{}/{}/restore?{}",
             crate::progenitor_support::encode_path(&package_type.to_string()),
             crate::progenitor_support::encode_path(&package_name.to_string()),
-            query
+            query_
         );
 
         self.client.post(&url, None).await
@@ -486,26 +466,22 @@ impl Packages {
         per_page: i64,
         state: crate::types::PackagesGetAllPackageVersionsOwnedByOrgState,
     ) -> Result<Vec<crate::types::PackageVersion>> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if page > 0 {
-            query_args.push(format!("page={}", page));
+            query_args.push(("page".to_string(), page.to_string()));
         }
         if per_page > 0 {
-            query_args.push(format!("per_page={}", per_page));
+            query_args.push(("per_page".to_string(), per_page.to_string()));
         }
-        query_args.push(format!("state={}", state));
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+        if !state.to_string().is_empty() {
+            query_args.push(("state".to_string(), state.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/user/packages/{}/{}/versions?{}",
             crate::progenitor_support::encode_path(&package_type.to_string()),
             crate::progenitor_support::encode_path(&package_name.to_string()),
-            query
+            query_
         );
 
         self.client.get(&url, None).await
@@ -531,20 +507,16 @@ impl Packages {
         package_name: &str,
         state: crate::types::PackagesGetAllPackageVersionsOwnedByOrgState,
     ) -> Result<Vec<crate::types::PackageVersion>> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
-        query_args.push(format!("state={}", state));
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+        let mut query_args: Vec<(String, String)> = Default::default();
+        if !state.to_string().is_empty() {
+            query_args.push(("state".to_string(), state.to_string()));
         }
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
         let url = format!(
             "/user/packages/{}/{}/versions?{}",
             crate::progenitor_support::encode_path(&package_type.to_string()),
             crate::progenitor_support::encode_path(&package_name.to_string()),
-            query
+            query_
         );
 
         self.client.get_all_pages(&url, None).await
